@@ -22,7 +22,9 @@ import re
 
 PICARD_ORG_NAME = "MusicBrainz"
 PICARD_APP_NAME = "Picard"
-PICARD_VERSION = (2, 0, 4, 'final', 0)
+PICARD_APP_ID = "org.musicbrainz.Picard"
+PICARD_DESKTOP_NAME = PICARD_APP_ID + ".desktop"
+PICARD_VERSION = (2, 2, 3, 'final', 0)
 
 
 # optional build version
@@ -87,4 +89,8 @@ else:
 # Keep those ordered
 api_versions = [
     "2.0",
+    "2.1",
+    "2.2",
 ]
+
+api_versions_tuple = [version_from_string(v) for v in api_versions]
