@@ -18,14 +18,23 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 
-import logging
+from functools import partial
 import os
 
-from functools import partial
+from PyQt5 import (
+    QtCore,
+    QtGui,
+    QtWidgets,
+)
+
+from picard import (
+    config,
+    log,
+)
+from picard.util import reconnect
 
-from PyQt5 import QtCore, QtGui, QtWidgets
-from picard import config, log
 from picard.ui import PicardDialog
+from picard.ui.colors import interface_colors
 
 
 class LogViewDialog(PicardDialog):
@@ -47,15 +56,28 @@ class LogViewDialog(PicardDialog):
 class LogViewCommon(LogViewDialog):
 
     def __init__(self, log_tail, *args, **kwargs):
-        self.displaying = False
-        self.prev = -1
-        self.log_tail = log_tail
-        self.log_tail.updated.connect(self._updated)
         super().__init__(*args, **kwargs)
+        self.displaying = False
+        self.log_tail = log_tail
+        self._init_doc()
 
-    def show(self):
-        self.display(clear=True)
-        super().show()
+    def _init_doc(self):
+        self.prev = -1
+        self.doc.clear()
+        self.textCursor.movePosition(QtGui.QTextCursor.Start)
+
+    def closeEvent(self, event):
+        event.ignore()
+        self.hide()
+
+    def hideEvent(self, event):
+        reconnect(self.log_tail.updated, None)
+        super().hideEvent(event)
+
+    def showEvent(self, event):
+        self.display()
+        reconnect(self.log_tail.updated, self._updated)
+        super().showEvent(event)
 
     def _updated(self):
         if self.displaying:
@@ -65,9 +87,7 @@ class LogViewCommon(LogViewDialog):
     def display(self, clear=False):
         self.displaying = True
         if clear:
-            self.prev = -1
-            self.doc.clear()
-            self.textCursor.movePosition(QtGui.QTextCursor.Start)
+            self._init_doc()
         for logitem in self.log_tail.contents(self.prev):
             self._add_entry(logitem)
             self.prev = logitem.pos
@@ -130,7 +150,7 @@ class LogView(LogViewCommon):
 
     def __init__(self, parent=None):
         super().__init__(log.main_tail, _("Log"), parent=parent)
-        self.verbosity = config.setting['log_verbosity']
+        self.verbosity = log.get_effective_level()
 
         self._setup_formats()
         self.hl_text = ''
@@ -139,9 +159,6 @@ class LogView(LogViewCommon):
         self.hbox = QtWidgets.QHBoxLayout()
         self.vbox.addLayout(self.hbox)
 
-        # Verbosity
-        if QtCore.QObject.tagger._debug:
-            self.verbosity = logging.DEBUG
         self.verbosity_menu_button = QtWidgets.QPushButton(_("Verbosity"))
         self.hbox.addWidget(self.verbosity_menu_button)
 
@@ -181,7 +198,6 @@ class LogView(LogViewCommon):
         self.hbox.addWidget(self.save_log_as_button)
         self.save_log_as_button.clicked.connect(self._save_log_as_do)
 
-
     def _clear_highlight_do(self):
         self.highlight_text.setText('')
         self.highlight_button.setEnabled(False)
@@ -207,13 +223,14 @@ class LogView(LogViewCommon):
             self.clear_highlight_button.setEnabled(bool(self.hl))
 
     def _setup_formats(self):
+        interface_colors.load_from_config()
         self.formats = {}
         font = QtGui.QFont()
         font.setFamily("Monospace")
         for level, feat in log.levels_features.items():
             text_fmt = QtGui.QTextCharFormat()
             text_fmt.setFont(font)
-            text_fmt.setForeground(QtGui.QColor(feat.fgcolor))
+            text_fmt.setForeground(interface_colors.get_qcolor(feat.color_key))
             self.formats[level] = text_fmt
 
     def _format(self, level):
@@ -280,7 +297,7 @@ class LogView(LogViewCommon):
     def _verbosity_changed(self, level):
         if level != self.verbosity:
             config.setting['log_verbosity'] = level
-            QtCore.QObject.tagger.debug(level == logging.DEBUG)
+            QtCore.QObject.tagger.set_log_level(level)
             self.verbosity = level
             self.display(clear=True)
 
